@@ -26,6 +26,7 @@
 
 #include <config.h>
 
+#include	"gobjectalias.h"
 #include        "gsignal.h"
 #include        "gbsearcharray.h"
 #include        "gvaluecollector.h"
@@ -709,7 +710,7 @@ signal_key_cmp (gconstpointer node1,
 }
 
 void
-g_signal_init (void) /* sync with gtype.c */
+g_signal_init (void)
 {
   SIGNAL_LOCK ();
   if (!g_n_signal_nodes)
@@ -824,12 +825,18 @@ g_signal_add_emission_hook (guint               signal_id,
 
   SIGNAL_LOCK ();
   node = LOOKUP_SIGNAL_NODE (signal_id);
-  if (!node || node->destroyed || (node->flags & G_SIGNAL_NO_HOOKS))
+  if (!node || node->destroyed)
     {
       g_warning ("%s: invalid signal id `%u'", G_STRLOC, signal_id);
       SIGNAL_UNLOCK ();
       return 0;
     }
+  if (node->flags & G_SIGNAL_NO_HOOKS) 
+    {
+      g_warning ("%s: signal id `%u' does not support emission hooks (G_SIGNAL_NO_HOOKS flag set)", G_STRLOC, signal_id);
+      SIGNAL_UNLOCK ();
+      return 0;
+    }
   if (detail && !(node->flags & G_SIGNAL_DETAILED))
     {
       g_warning ("%s: signal id `%u' does not support detail (%u)", G_STRLOC, signal_id, detail);
